/* GNU FaXile - fax image viewer
 *
 * Copyright (C) 2000 Wolfgang Sourdeau
 *
 * Author: Wolfgang Sourdeau <wolfgang@ultim.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef VIEWER_H
#define VIEWER_H

#ifdef ENABLE_NLS
#    include <libintl.h>
#    undef _
#    define _(String) dgettext (PACKAGE, String)
#    ifdef gettext_noop
#        define N_(String) gettext_noop (String)
#    else
#        define N_(String) (String)
#    endif
#else
/* Stubs that do something close enough.  */
#    define textdomain(String) (String)
#    define gettext(String) (String)
#    define dgettext(Domain,Message) (Message)
#    define dcgettext(Domain,Message,Type) (Message)
#    define bindtextdomain(Domain,Directory) (Domain)
#    define _(String) (String)
#    define N_(String) (String)
#endif

typedef struct _ViewerData ViewerData;
typedef struct _DrawReqData DrawReqData;
typedef struct _MotionData MotionData;

struct _ViewerData {
	gchar *file_name;
	FaxFile *fax_file;
	FaxPage *current_page;
	gint zoom_index;

	GdkPixmap *page_pixmap;
	GtkWidget *viewer_window;
	GtkWidget *page_area;
	int reverse_page;

        /* button bar */
	GtkWidget *bb_buttons[4];

	/* print dialog */
	GtkWidget *print_dialog;

	/* thumbnails */
	GtkWidget **th_buttons;

        /* Cursor motion data */
	MotionData *motion_data;
};

struct _MotionData {
	guint dragging:1;
	guint orig_x, orig_y;
	gfloat orig_adj_x, orig_adj_y;
};

struct _DrawReqData {
	ViewerData *viewer_data;
	FaxPage *requested_page;
};

typedef enum {
	NEXT_PAGE,
	PREV_PAGE,
	ZOOM_IN,
	ZOOM_OUT
} ButtonBarIndexes;

#endif
